@@ -22,7 +22,10 @@ def rollover(serviceConfig, serviceState, state):
     log.info('  -> Rspamd reload')
     try:
         rv = check_output(('systemctl', 'start', 'rspamd'))
-        rv = check_output(('systemctl', 'reload', 'rspamd'))
+        #rv = check_output(('systemctl', 'reload', 'rspamd')) # this is not working with rspamd
+        #rv = check_output(('rspamadm', 'control', 'reload'))
+        # only restart works - bug in rspamd
+        rv = check_output(('systemctl', 'restart', 'rspamd'))
     except CalledProcessError as e:
         log.error(e.output)
         raise(e)
